@@ -21,22 +21,25 @@ class LaterValue(object):
         return "_value" in self.__dict__
 
 @rule
-def all_but(but, escape="\\", re_flags=0):
+def all_but(but, escape="\\"):
     """
     """
 
     if not isinstance(but, list):
         but = [but]
 
-    but = [re.escape(a) for a in but]
+    _not = "|".join([re.escape(b) for b in but])
 
     if escape:
-        escaped = [escape + a for a in but]
-        regexp = "({0}|[^{1}])+".format("|".join(escaped), "".join(but))
+        escaped = [escape + re.escape(a) for a in but]
     else:
-        regexp = "[^{0}]+".format("".join(but))
+        escaped = []
 
-    return re.compile(regexp, re_flags)
+    escaped.append(".")
+    _valid = "|".join(escaped)
+    regexp = "((?!{_not})({_valid}))+".format(_not=_not, _valid=_valid)
+
+    return re.compile(regexp, re.DOTALL)
 
 @rule(skip=None)
 def balanced(start, end, escape="\\"):
